variable "availability_zones" {
  type        = list(string)
  description = "(Optional) Availability zones where the DAX nodes will be deployed"
  default     = []
}

variable "cluster_name" {
  type        = string
  description = "(Required) Name of the DAX cluster"
}

variable "description" {
  type        = string
  description = "(Optional) Description for the DAX cluster"
  default     = "DAX Cluster"
}

variable "dynamodb_tables_arns" {
  type        = list(string)
  description = "(Required) ARNs of DynamoDB tables that the DAX cluster will be able to access"
  default     = []
}

variable "dax_iam_role_arn" {
  type    = string
  default = ""
}

variable "encryption_type" {
  type        = string
  description = "(Optional) The type of encryption the cluster's endpoint should support. Valid values are: NONE and TLS."
  default     = "TLS"
}

variable "iam_prefix" {
  type        = string
  description = "(Required) Prefix for names of IAM resources"
}

variable "maintenance_window" {
  type        = string
  description = "(Optional) Specifies the weekly time range for when maintenance on the cluster is performed. The format is ddd:hh24:mi-ddd:hh24:mi (24H Clock UTC). Can't be less than 60 minutes."
  default     = "sun:00:00-sun:01:00"
}

variable "node_type" {
  type        = string
  description = "(Required) The type of the DAX cluster nodes"
}

variable "notification_topic_arn" {
  type        = string
  description = "(Optional) ARN of an SNS topic to send DAX notifications to"
  default     = null
}

variable "query_ttl" {
  type        = string
  description = "(Optional) Query TTL in milliseconds"
  default     = "300000"
}

variable "record_ttl" {
  type        = string
  description = "(Optional) Record TTL in milliseconds"
  default     = "300000"
}

variable "replication_factor" {
  type        = number
  description = "(Required) Number of nodes in the DAX cluster"
  default     = 1
}

variable "security_group_ids" {
  type        = list(string)
  description = "(Optional) List of one or more security groups to be associated with the DAX cluster"
  default     = []
}

variable "server_side_encryption" {
  type        = bool
  description = "(Optional) Encrypt data in the DAX cluster at rest"
  default     = true
}

variable "subnet_ids" {
  type        = list(string)
  description = "(Required) List of one or more subnets to be use for the DAX cluster subnet group"
  default     = []
}

variable "tags" {
  type        = map(string)
  description = "(Optional) Tags for all DAX related resources"
}

variable "enable_iam_policies" {
  type    = bool
  default = true
}
